# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/bixo/blacklist/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/bixo/blacklist/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Bixo\\Blacklist\\": "packages/bixo/blacklist/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Bixo\Blacklist\Providers\BlacklistServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Blacklist'  => Bixo\Blacklist\Facades\Blacklist::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Bixo\\BlacklistTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Bixo\Blacklist\Providers\BlacklistServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Bixo\Blacklist\Providers\BlacklistServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Bixo\Blacklist\Providers\BlacklistServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/blacklist/{modulename}

**User**

    http://path-to-route-folder/user/blacklist/{modulename}

**Public**

    http://path-to-route-folder/blacklists


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/blacklist/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/blacklist/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/blacklist/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/blacklist/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/blacklist/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/blacklist/{modulename}/{slug}
    METHOD: GET